<!DOCTYPE TS><TS>
<defaultcodec></defaultcodec>
<context>
    <name>AdvSearch</name>
    <message>
        <source>All clauses</source>
        <translation>Tüm ifadeler</translation>
    </message>
    <message>
        <source>Any clause</source>
        <translation>İfadelerin herhangi biri</translation>
    </message>
    <message>
        <source>texts</source>
        <translation>metinler</translation>
    </message>
    <message>
        <source>spreadsheets</source>
        <translation>hesap tabloları</translation>
    </message>
    <message>
        <source>presentations</source>
        <translation>sunumlar</translation>
    </message>
    <message>
        <source>media</source>
        <translation>ortamlar</translation>
    </message>
    <message>
        <source>messages</source>
        <translation>iletiler</translation>
    </message>
    <message>
        <source>other</source>
        <translation>diğer</translation>
    </message>
    <message>
        <source>Cannot execute pure negative query. Please enter common terms in the &apos;any words&apos; field</source>
        <translation>Tamamen negatif sorgu çalıştırılamaz. Lütfen &apos;herhangi bir sözcük&apos; alanına genel ifadeler girin</translation>
    </message>
</context>
<context>
    <name>AdvSearchBase</name>
    <message>
        <source>Advanced search</source>
        <translation>Gelişmiş arama</translation>
    </message>
    <message>
        <source>Search for &lt;br&gt;documents&lt;br&gt;satisfying:</source>
        <translation>Uyan &lt;br&gt;belgeleri&lt;br&gt;ara:</translation>
    </message>
    <message>
        <source>All non blank fields will be combined with OR or AND conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
        <translation type="obsolete">Tüm boş alanlar VEYA ya da VE bağlaçları ile birleştirilecek. &lt;br&gt; &quot;Herhangi biri&quot; &quot;Tümü&quot; ve &quot;Hiçbiri&quot; alan tipleri basit sözcüklerin karışımını ve çift tırnak içine alınmış ifadeleri kabul edebilir.&lt;br&gt;Veri içermeyen alanlar yoksayılır.</translation>
    </message>
    <message>
        <source>Delete clause</source>
        <translation>İfadeyi sil</translation>
    </message>
    <message>
        <source>Add clause</source>
        <translation>İfade ekle</translation>
    </message>
    <message>
        <source>Restrict file types</source>
        <translation>Dosya tiplerini sınırlandır</translation>
    </message>
    <message>
        <source>Check this to enable filtering on file types</source>
        <translation>Dosya tipleri üzerinde filtreleme kullanmak için bunu işaretleyin</translation>
    </message>
    <message>
        <source>By categories</source>
        <translation>Kategorilere göre</translation>
    </message>
    <message>
        <source>Check this to use file categories instead of raw mime types</source>
        <translation>Dosya tipleri yerine ham mime tipleri üzerinde filtreleme kullanmak için bunu işaretleyin</translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation>öntanımlı olarak kaydet</translation>
    </message>
    <message>
        <source>Searched file types</source>
        <translation>Aranan dosya tipleri</translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation>Tümü ----&gt;</translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation>Seç -----&gt;</translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation>&lt;----- Seç</translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation>&lt;----- Tümü</translation>
    </message>
    <message>
        <source>Ignored file types</source>
        <translation>Yoksayılan dosya tipleri</translation>
    </message>
    <message>
        <source>Enter top directory for search</source>
        <translation>Arama için en üst dizini girin</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Gözat</translation>
    </message>
    <message>
        <source>Restrict results to files in subtree:</source>
        <translation>Arama sonuçlarını bu dizin ve aşağısı ile sınırlandır:</translation>
    </message>
    <message>
        <source>Start Search</source>
        <translation>Aramayı Başlat</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>All non empty fields on the right will be combined with AND (&quot;All clauses&quot; choice) or OR (&quot;Any clause&quot; choice) conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Configuration problem: </source>
        <translation type="obsolete">Yapılandırma sorunu: </translation>
    </message>
    <message>
        <source>Configuration problem (dynconf</source>
        <translation>Yapılandırma sorunu</translation>
    </message>
    <message>
        <source>No db directory in configuration</source>
        <translation>Yapılandırma içerisinde veritabanı dizini yok</translation>
    </message>
    <message>
        <source>Could not open database in </source>
        <translation>Veritabanı açılamadı</translation>
    </message>
    <message>
        <source>.
Click Cancel if you want to edit the configuration file before indexation starts, or Ok to let it proceed.</source>
        <translation>.
İndekseleme başlamadan yapılandırmayı düzenlemek için İptal düğmesine basın ya da Tamam düğmesine basarak işleme izin verin.</translation>
    </message>
</context>
<context>
    <name>Preview</name>
    <message>
        <source>Close Tab</source>
        <translation>Sekmeyi Kapat</translation>
    </message>
    <message>
        <source>Cannot create temporary directory</source>
        <translation>Geçici dizin oluşturulamadı</translation>
    </message>
    <message>
        <source>File does not exist</source>
        <translation>Dosya yok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Missing helper program: </source>
        <translation>Yardımcı program kayıp: </translation>
    </message>
    <message>
        <source>Can&apos;t turn doc into internal representation for </source>
        <translation>Şunun için iç gösterim yapılamıyor</translation>
    </message>
    <message>
        <source>Creating preview text</source>
        <translation>Önizleme metni oluşturuluyor</translation>
    </message>
    <message>
        <source>Loading preview text into editor</source>
        <translation>Önizleme metni düzenleyiciye yükleniyor</translation>
    </message>
    <message>
        <source>&amp;Search for:</source>
        <translation type="unfinished">A&amp;ra:</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation type="unfinished">&amp;Sonraki</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation type="unfinished">&amp;Önceki</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">Temizle</translation>
    </message>
    <message>
        <source>Match &amp;Case</source>
        <translation type="unfinished">Eşleşme Şa&amp;rtı</translation>
    </message>
</context>
<context>
    <name>PreviewBase</name>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Önizle</translation>
    </message>
    <message>
        <source>Preview 1</source>
        <translation type="obsolete">Önizleme 1</translation>
    </message>
    <message>
        <source>&amp;Search for:</source>
        <translation type="obsolete">A&amp;ra:</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation type="obsolete">&amp;Sonraki</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="obsolete">Alt+S</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation type="obsolete">&amp;Önceki</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation type="obsolete">Alt+Ö</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="obsolete">Temizle</translation>
    </message>
    <message>
        <source>Match &amp;Case</source>
        <translation type="obsolete">Eşleşme Şa&amp;rtı</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+R</translation>
    </message>
</context>
<context>
    <name>PreviewTextEdit</name>
    <message>
        <source>Show fields</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show main text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Global parameters</source>
        <translation>Genel parametreler</translation>
    </message>
    <message>
        <source>Local parameters</source>
        <translation>Yerel parametreler</translation>
    </message>
    <message>
        <source>&lt;b&gt;Customised subtrees</source>
        <translation>&lt;b&gt;Özelleştirilmiş alt ağaçlar</translation>
    </message>
    <message>
        <source>The list of subdirectories in the indexed hierarchy &lt;br&gt;where some parameters need to be redefined. Default: empty.</source>
        <translation>İndekslenmiş sıralama içerisindeki alt dizinlerin listesi &lt;br&gt;ki burada bazı parametrelerin yeniden tanımlanması gerekir. Öntanımlı: boş.</translation>
    </message>
    <message>
        <source>&lt;i&gt;The parameters that follow are set either at the top level, if nothing&lt;br&gt;or an empty line is selected in the listbox above, or for the selected subdirectory.&lt;br&gt;You can add or remove directories by clicking the +/- buttons.</source>
        <translation>&lt;i&gt;Aşağıdaki parametreler, ya seçili alt dizin için uygulanır ya da üst düzeyde veya üstteki metin kutusunda hiçbir şey seçilmediğinde yada boş bir satır seçildiğinde uygulanır.&lt;br&gt;+/- düğmelerine tıklayarak dizinleri ekleyip çıkarabilirsiniz.</translation>
    </message>
    <message>
        <source>Skipped names</source>
        <translation>Atlanan isimler</translation>
    </message>
    <message>
        <source>These are patterns for file or directory  names which should not be indexed.</source>
        <translation>Bu nitelikler insekslenmemesi  gereken dosya ve dizinler içindir.</translation>
    </message>
    <message>
        <source>Default character set</source>
        <translation>Öntanımlı karakter seti</translation>
    </message>
    <message>
        <source>This is the character set used for reading files which do not identify the character set internally, for example pure text files.&lt;br&gt;The default value is empty, and the value from the NLS environnement is used.</source>
        <translation>Bu karakter seti, karakter kodlaması uygulama tarafından belirlenemeyen dosyalar için kulanılır, Örneğin salt metin dosyaları.&lt;br&gt;Öntanımlı değer boştur ve NLS çevresel değişkeni kullanılır.</translation>
    </message>
    <message>
        <source>Follow symbolic links</source>
        <translation>Sembolik bağlantıları izle</translation>
    </message>
    <message>
        <source>Follow symbolic links while indexing. The default is no, to avoid duplicate indexing</source>
        <translation>İndekslerken sembolik bağlantıları izle. Aynı ögelerin yeniden indekslenmesinden kaçınmak için öntanımlı değer hayır</translation>
    </message>
    <message>
        <source>Index all file names</source>
        <translation>Tüm dosya isimlerini indeksle</translation>
    </message>
    <message>
        <source>Index the names of files for which the contents cannot be identified or processed (no or unsupported mime type). Default true</source>
        <translation>İçeriği tanınmayan ya da işlenemeyen (ya da desteklenmeyen mime tipi) dosyaları indeksle. Öntanımlı evet</translation>
    </message>
</context>
<context>
    <name>QtGuiResListPager</name>
    <message>
        <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
        <translation type="obsolete">&lt;p&gt;&lt;b&gt;Sonuç bulunamadı&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="obsolete">Önceki</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="obsolete">Sonraki</translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation type="obsolete">Erişilemez belge</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Önizle</translation>
    </message>
    <message>
        <source>(show query)</source>
        <translation type="obsolete">(sorguyu göster)</translation>
    </message>
</context>
<context>
    <name>RclMain</name>
    <message>
        <source>(no stemming)</source>
        <translation>(kök ayrıştırma kullanma)</translation>
    </message>
    <message>
        <source>(all languages)</source>
        <translation>(tüm diller)</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>sözcük kökleri ayrıştırılabilir diller alınırken hata oluştu</translation>
    </message>
    <message>
        <source>Indexing in progress: </source>
        <translation>İndeksleme devam ediyor: </translation>
    </message>
    <message>
        <source>Files</source>
        <translation>Dosyalar</translation>
    </message>
    <message>
        <source>Purge</source>
        <translation>Temizle</translation>
    </message>
    <message>
        <source>Stemdb</source>
        <translation>KökAyrıştırmaVeritabanı</translation>
    </message>
    <message>
        <source>Closing</source>
        <translation>Kapatılıyor</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Bilinmeyen</translation>
    </message>
    <message>
        <source>Can&apos;t start query: </source>
        <translation>Sorgu başlatılamadı: </translation>
    </message>
    <message>
        <source>Query results</source>
        <translation>Arama Sonuçları</translation>
    </message>
    <message>
        <source>Query results (sorted)</source>
        <translation type="obsolete">Arama sonuçları (sıralanmış)</translation>
    </message>
    <message>
        <source>Cannot retrieve document info from database</source>
        <translation>Veritabanından belge bilgileri alınamadı</translation>
    </message>
    <message>
        <source>Cannot access document file: </source>
        <translation>Belge dosyasına erişilemedi: </translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Uyarı</translation>
    </message>
    <message>
        <source>Can&apos;t create preview window</source>
        <translation>Önizleme penceresi oluşturulamıyor</translation>
    </message>
    <message>
        <source>This search is not active any more</source>
        <translation>Bu arama atrık etkin değil</translation>
    </message>
    <message>
        <source>No external viewer configured for mime type </source>
        <translation>Mime tipi için bir dış gösterici ayarlanmamış</translation>
    </message>
    <message>
        <source>Bad viewer command line for %1: [%2]
Please check the mimeconf file</source>
        <translation>%1 için uygun olmayan komut: [%2]
Lütfen mimeconf dosyasını kontrol edin</translation>
    </message>
    <message>
        <source>The viewer specified in mimeconf for %1: %2 is not found.
Do you want to start the  preferences dialog ?</source>
        <translation>%1 için mimeconf dosyasında belirtilen gösterici: %2 bulunamadı.
Tercihler penceresini  açmak ister misiniz?</translation>
    </message>
    <message>
        <source>Cannot extract document or create temporary file</source>
        <translation>Belge açılamadı ya da geçici dosya oluşturulamadı</translation>
    </message>
    <message>
        <source>Executing: [</source>
        <translation>Çalıştırılıyor: [</translation>
    </message>
    <message>
        <source>About Recoll</source>
        <translation>Recoll Hakkında</translation>
    </message>
    <message>
        <source>Starting help browser </source>
        <translation type="obsolete">Yardım tarayıcıyı başlat </translation>
    </message>
    <message>
        <source>History data</source>
        <translation>Geçmiş verileri</translation>
    </message>
    <message>
        <source>Document history</source>
        <translation>Belge geçmişi</translation>
    </message>
    <message>
        <source>Update &amp;Index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indexing interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop &amp;Indexing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>media</source>
        <translation type="unfinished">ortamlar</translation>
    </message>
    <message>
        <source>message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>other</source>
        <translation type="unfinished">diğer</translation>
    </message>
    <message>
        <source>presentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sorted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>filtered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>External applications/commands needed and not found for indexing your file types:

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No helpers found missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing helper programs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save file dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose a file name to save under</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RclMainBase</name>
    <message>
        <source>Recoll</source>
        <translation>Recoll</translation>
    </message>
    <message>
        <source>Search tools</source>
        <translation>Arama araçları</translation>
    </message>
    <message>
        <source>Result list</source>
        <translation>Sonuç listesi</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Dosya</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Araçlar</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Tercihler</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Çık</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Update &amp;index</source>
        <translation>İndeksi g&amp;üncelle</translation>
    </message>
    <message>
        <source>&amp;Erase document history</source>
        <translation>&amp;Belge geçmişini temizle</translation>
    </message>
    <message>
        <source>&amp;About Recoll</source>
        <translation>&amp;Recoll Hakkında</translation>
    </message>
    <message>
        <source>&amp;User manual</source>
        <translation>&amp;Kullanıcı El Kitabı</translation>
    </message>
    <message>
        <source>Document &amp;History</source>
        <translation>Belge &amp;Geçmişi</translation>
    </message>
    <message>
        <source>Document  History</source>
        <translation>Belge  Geçmişi</translation>
    </message>
    <message>
        <source>&amp;Advanced Search</source>
        <translation>&amp;Gelişmiş arama</translation>
    </message>
    <message>
        <source>Advanced/complex  Search</source>
        <translation>Gelişmiş/karmaşık   Arama</translation>
    </message>
    <message>
        <source>&amp;Sort parameters</source>
        <translation>&amp;Sıralama Ölçütleri</translation>
    </message>
    <message>
        <source>Sort parameters</source>
        <translation>Sıralama ölçütleri</translation>
    </message>
    <message>
        <source>Term &amp;explorer</source>
        <translation>İfade g&amp;österici</translation>
    </message>
    <message>
        <source>Term explorer tool</source>
        <translation>İfade gösterme aracı</translation>
    </message>
    <message>
        <source>Next page</source>
        <translation>Sonraki sayfa</translation>
    </message>
    <message>
        <source>Next page of results</source>
        <translation>Sonuçların sonraki sayfası</translation>
    </message>
    <message>
        <source>First page</source>
        <translation>İlk sayfa</translation>
    </message>
    <message>
        <source>Go to first page of results</source>
        <translation>Sonuçların ilk sayfasına git</translation>
    </message>
    <message>
        <source>Previous page</source>
        <translation>Önceki sayfa</translation>
    </message>
    <message>
        <source>Previous page of results</source>
        <translation>Sonuçların önceki sayfası</translation>
    </message>
    <message>
        <source>&amp;Query configuration</source>
        <translation>&amp;Sorgu yapılandırması</translation>
    </message>
    <message>
        <source>External index dialog</source>
        <translation>Dış indeksler penceresi</translation>
    </message>
    <message>
        <source>&amp;Indexing configuration</source>
        <translation>İ&amp;ndeksleme yapılandırması </translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Show missing helpers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResList</name>
    <message>
        <source>Result list</source>
        <translation>Sonuç listesi</translation>
    </message>
    <message>
        <source>Show query details</source>
        <translation type="obsolete">Sorgu detaylarını göster</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
        <translation type="unfinished">&lt;p&gt;&lt;b&gt;Sonuç bulunamadı&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; out of at least &lt;b&gt;%3&lt;/b&gt; for </source>
        <translation type="obsolete">Toplam &lt;b&gt;%3&lt;/b&gt; sonucun &lt;b&gt;%1-%2&lt;/b&gt; arası, sorgu </translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; for </source>
        <translation type="obsolete">Sonuçlar &lt;b&gt;%1-%2&lt;/b&gt; arası, sorgu </translation>
    </message>
    <message>
        <source>(show query)</source>
        <translation>(sorguyu göster)</translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation type="unfinished">Erişilemez belge</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished">Önceki</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished">Sonraki</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Önizle</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Düzenle</translation>
    </message>
    <message>
        <source>Copy &amp;File Name</source>
        <translation>&amp;Dosya Adını Kopyala</translation>
    </message>
    <message>
        <source>Copy &amp;URL</source>
        <translation>&amp;Adresi Kopyala</translation>
    </message>
    <message>
        <source>Find &amp;similar documents</source>
        <translation>Benzer belgeleri &amp;bul</translation>
    </message>
    <message>
        <source>P&amp;arent document/folder</source>
        <translation>Ü&amp;st belge/dizin</translation>
    </message>
    <message>
        <source>Query details</source>
        <translation>Sorgu detayları</translation>
    </message>
    <message>
        <source>filtered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sorted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document history</source>
        <translation type="unfinished">Belge geçmişi</translation>
    </message>
    <message>
        <source>Save to File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; out of at least &lt;b&gt;%d&lt;/b&gt; for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished">Önizle</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SSearch</name>
    <message>
        <source>Any term</source>
        <translation>Sözcüklerin herhangi biri</translation>
    </message>
    <message>
        <source>All terms</source>
        <translation>Tüm sözcükler</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Dosya adı</translation>
    </message>
    <message>
        <source>Query language</source>
        <translation>Arama dili</translation>
    </message>
    <message>
        <source>Bad query string</source>
        <translation>Uygunsuz arama ifadesi</translation>
    </message>
    <message>
        <source>Out of memory</source>
        <translation>Yetersiz bellek</translation>
    </message>
    <message>
        <source>Too many completions</source>
        <translation>Çok fazla tamamlama</translation>
    </message>
    <message>
        <source>Completions</source>
        <translation>Tamamlamalar</translation>
    </message>
    <message>
        <source>Select an item:</source>
        <translation>Bir öge seçin:</translation>
    </message>
</context>
<context>
    <name>SSearchBase</name>
    <message>
        <source>SSearchBase</source>
        <translation>SSearchBase</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Temizle</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Erase search entry</source>
        <translation>Arama girdisini temizle</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>Start query</source>
        <translation>Sorguyu başlat</translation>
    </message>
    <message>
        <source>Choose type of search: any term, all terms, filename with possible wildcards.</source>
        <translation type="obsolete">Arama tipini seçin: herhangi bir sözcük, tüm sözcükler, özel karakterler de kullanılabilen dosya adı.</translation>
    </message>
    <message>
        <source>Enter search terms here. Type ESC SPC for completions of current term.</source>
        <translation>Aranacak ifadeleri buraya girin. Geçerli sözcüğün tamamlanması için ESC SPACE kullanın.</translation>
    </message>
    <message>
        <source>Choose search type.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchClauseW</name>
    <message>
        <source>SearchClauseW</source>
        <translation>SearchClauseW</translation>
    </message>
    <message>
        <source>Any of these</source>
        <translation>Bunların herhangi biri</translation>
    </message>
    <message>
        <source>All of these</source>
        <translation>Bunların tümü</translation>
    </message>
    <message>
        <source>None of these</source>
        <translation>Bunların hiçbiri</translation>
    </message>
    <message>
        <source>This phrase</source>
        <translation>Tam olarak bu ifade</translation>
    </message>
    <message>
        <source>Terms in proximity</source>
        <translation>Yakın ifadeler</translation>
    </message>
    <message>
        <source>File name matching</source>
        <translation>Dosya adı eşleşen</translation>
    </message>
    <message>
        <source>Select the type of query that will be performed with the words</source>
        <translation>Sözcükler ile kullanılacak sorgu biçimini seç</translation>
    </message>
    <message>
        <source>Number of additional words that may be interspersed with the chosen ones</source>
        <translation>Seçilen sözcüklerin arasında yer alabilecek ek sözcüklerin sayısı</translation>
    </message>
</context>
<context>
    <name>SortForm</name>
    <message>
        <source>Date</source>
        <translation>Tarih</translation>
    </message>
    <message>
        <source>Mime type</source>
        <translation>Mime Tipi</translation>
    </message>
</context>
<context>
    <name>SortFormBase</name>
    <message>
        <source>Sort Criteria</source>
        <translation>Sıralama Ölçütü</translation>
    </message>
    <message>
        <source>Sort the</source>
        <translation>Sırala</translation>
    </message>
    <message>
        <source>most relevant results by:</source>
        <translation>en uygun sonuç veren:</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation>Azalan</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>SpellBase</name>
    <message>
        <source>Term Explorer</source>
        <translation>İfade Gösterici</translation>
    </message>
    <message>
        <source>&amp;Expand </source>
        <translation>&amp;Genişlet </translation>
    </message>
    <message>
        <source>Alt+E</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+K</translation>
    </message>
    <message>
        <source>Term</source>
        <translation>İfade</translation>
    </message>
    <message>
        <source>Count</source>
        <translation>Sayı</translation>
    </message>
</context>
<context>
    <name>SpellW</name>
    <message>
        <source>Wildcards</source>
        <translation>Özel karakterler</translation>
    </message>
    <message>
        <source>Regexp</source>
        <translation>Düzenli ifade</translation>
    </message>
    <message>
        <source>Stem expansion</source>
        <translation>Kök ayrıştırma genişlemesi</translation>
    </message>
    <message>
        <source>Spelling/Phonetic</source>
        <translation>Heceleme/Fonetik</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>sözcük kökleri ayrıştırılabilir diller alınırken hata oluştu</translation>
    </message>
    <message>
        <source>Aspell init failed. Aspell not installed?</source>
        <translation>Aspell başlatılamadı. Yüklenmemiş olabilir mi?</translation>
    </message>
    <message>
        <source>Aspell expansion error. </source>
        <translation>Aspell heceleme genişlemesi hatası. </translation>
    </message>
    <message>
        <source>No expansion found</source>
        <translation>Hiç genişleme bulunamadı</translation>
    </message>
</context>
<context>
    <name>UIPrefsDialog</name>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>sözcük kökleri ayrıştırılabilir diller alınırken hata oluştu</translation>
    </message>
    <message>
        <source>The selected directory does not appear to be a Xapian index</source>
        <translation>Seçilen dizin bir Xapian indeks dizini gibi görünmüyor</translation>
    </message>
    <message>
        <source>This is the main/local index!</source>
        <translation>Bu ana/yerel veritabanı!</translation>
    </message>
    <message>
        <source>The selected directory is already in the index list</source>
        <translation>Seçilen dizin zaten indeks listesinde var</translation>
    </message>
    <message>
        <source>Select xapian index directory (ie: /home/buddy/.recoll/xapiandb)</source>
        <translation>Xapian indeks dizinini seç (/home/kullanıcı_adınız/.recoll/xapiandb gibi.)</translation>
    </message>
</context>
<context>
    <name>UIPrefsDialogBase</name>
    <message>
        <source>User preferences</source>
        <translation>Kullanıcı tercihleri</translation>
    </message>
    <message>
        <source>User interface</source>
        <translation>Kullanıcı arayüzü</translation>
    </message>
    <message>
        <source>Number of entries in a result page</source>
        <translation>Bir sonuç sayfasındaki sonuç sayısı</translation>
    </message>
    <message>
        <source>Result list font</source>
        <translation>Sonuç listesi yazıtipi</translation>
    </message>
    <message>
        <source>Helvetica-10</source>
        <translation>Helvetica-10</translation>
    </message>
    <message>
        <source>Opens a dialog to select the result list font</source>
        <translation>Sonuç listesi yazıtipini seçmek için bir pencere açar</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Sıfırla</translation>
    </message>
    <message>
        <source>Resets the result list font to the system default</source>
        <translation>Sonuç listesi yazıtipini sistem ayarlarına döndür</translation>
    </message>
    <message>
        <source>Result paragraph&lt;br&gt;format string</source>
        <translation>Sonuç paragrafı&lt;br&gt;biçimlendirme ifadesi</translation>
    </message>
    <message>
        <source>Defines the format for each result list paragraph. Use qt html format and printf-like replacements:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</source>
        <translation>Tüm sonuç listesi paragraflarını tanımlar. Qt html biçimini ve printf benzeri yer değiştiricileri kullanın:&lt;br&gt;%A Özet&lt;br&gt; %D Tarih&lt;br&gt; %I Simge resminin adı&lt;br&gt; %K Anahtar sözcükler (eğer varsa)&lt;br&gt; %L Önizle ve Düzenle bağlantıları&lt;br&gt; %M Mime tipi&lt;br&gt; %N Sonuç sayısı&lt;br&gt; %R Uyum yüzdesi&lt;br&gt; %S Boyut bilgileri&lt;br&gt; %T Başlık&lt;br&gt; %U Url&lt;br&gt;</translation>
    </message>
    <message>
        <source>Texts over this size will not be highlighted in preview (too slow).</source>
        <translation>Bu boyuttan büyük metinler önizlemede vurgulanmayacak (çok yavaş).</translation>
    </message>
    <message>
        <source>Maximum text size highlighted for preview (megabytes)</source>
        <translation>Önizlemede vurgulanacak en fazla metin boyutu (MB)</translation>
    </message>
    <message>
        <source>HTML help browser</source>
        <translation type="obsolete">HTML yardım tarayıcı</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation type="obsolete">Dosya seç</translation>
    </message>
    <message>
        <source>Choose external viewer applications</source>
        <translation type="obsolete">Dış gösterici uygulamaları seç</translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="obsolete">Yönet</translation>
    </message>
    <message>
        <source>Auto-start simple search on whitespace entry.</source>
        <translation>Beyaz alan girdisi olduğunda basit aramayı otomatik olarak başlat.</translation>
    </message>
    <message>
        <source>Start with advanced search dialog open.</source>
        <translation>Gelişmiş arama penceresi ile başla.</translation>
    </message>
    <message>
        <source>Start with sort dialog open.</source>
        <translation>Sıralama penceresi ile başla.</translation>
    </message>
    <message>
        <source>Use desktop preferences to choose document editor.</source>
        <translation>Belge düzenleyiciyi seçmek için masaüstü tercihlerini kullan.</translation>
    </message>
    <message>
        <source>Remember sort activation state.</source>
        <translation>Sıralama kurallarını hatırla.</translation>
    </message>
    <message>
        <source>Search parameters</source>
        <translation>Arama parametreleri</translation>
    </message>
    <message>
        <source>Stemming language</source>
        <translation>Kök ayrıştırma dili</translation>
    </message>
    <message>
        <source>Automatically add phrase to simple searches</source>
        <translation>Basit aramalara ifadeyi otomatik olarak ekle</translation>
    </message>
    <message>
        <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)]. 
This should give higher precedence to the results where the search terms appear exactly as entered.</source>
        <translation>[linux kernel] (2 sözcük) araması [linux veya kernel veya (linux ifadesi 2 tane kernel)] olarak değiştirilecektir.  
Bu, aranacak sözcüklerin tam olarak girildiği gibi görüntülendiği sonuçlara yüksek öncelik verilmesini sağlayacaktır.</translation>
    </message>
    <message>
        <source>Dynamically build abstracts</source>
        <translation>Özetleri dinamik olarak oluştur</translation>
    </message>
    <message>
        <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
May be slow for big documents.</source>
        <translation>Sorgu sözcükleri kullanılarak sonuç listesi girdileri için özet oluşturulsun mu ? 
Büyük boyutlu belgelerde yavaş olabilir.</translation>
    </message>
    <message>
        <source>Replace abstracts from documents</source>
        <translation>Belgelerden özetleri kaldır</translation>
    </message>
    <message>
        <source>Do we synthetize an abstract even if the document seemed to have one?</source>
        <translation>Belgenin bir özeti varsa bile bir yapay özet oluşturulsun mu?</translation>
    </message>
    <message>
        <source>Synthetic abstract size (characters)</source>
        <translation>Yapay özet boyutu (karakter sayısı)</translation>
    </message>
    <message>
        <source>Synthetic abstract context words</source>
        <translation>Yapay özet sözcükleri</translation>
    </message>
    <message>
        <source>External Indexes</source>
        <translation>Dış indeksler</translation>
    </message>
    <message>
        <source>External indexes</source>
        <translation>Dış indeksler</translation>
    </message>
    <message>
        <source>Toggle selected</source>
        <translation>Seç /Bırak</translation>
    </message>
    <message>
        <source>Activate All</source>
        <translation>Tümünü Etkinleştir</translation>
    </message>
    <message>
        <source>Deactivate All</source>
        <translation>Tümünü Pasifleştir</translation>
    </message>
    <message>
        <source>Remove selected</source>
        <translation>Seçileni sil</translation>
    </message>
    <message>
        <source>Remove from list. This has no effect on the disk index.</source>
        <translation>Listeden sil. Bu diskteki indeksi etkilemez.</translation>
    </message>
    <message>
        <source>Add index</source>
        <translation>İndeks ekle</translation>
    </message>
    <message>
        <source>Select the xapiandb directory for the index you want to add, then click Add Index</source>
        <translation>İstediğiniz indeksi eklemek için xapiandb (veritabanı) dizinini seçin ve İndeks Ekle düğmesine tıklayın</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Gözat</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;TAMAM</translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation>Değişiklikleri uygula</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;İptal</translation>
    </message>
    <message>
        <source>Discard changes</source>
        <translation>Değişiklikleri sil</translation>
    </message>
    <message>
        <source>Highlight color for query terms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prefer Html to plain text for preview.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If checked, results with the same content under different names will only be shown once.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide duplicate results.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose editor applications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewAction</name>
    <message>
        <source>Changing actions with different current values</source>
        <translation>Farklı değerlerle eylemler değiştiriliyor</translation>
    </message>
</context>
<context>
    <name>ViewActionBase</name>
    <message>
        <source>Native Viewers</source>
        <translation>Doğal Göstericiler</translation>
    </message>
    <message>
        <source>Select one or several file types, then click Change Action to modify the program used to open them</source>
        <translation>Bir ya da birkaç dosya tipi seçin ve Eylemi Değiştir düğmesine tıklayarak hangi uygulama ile açılacağını değiştirin</translation>
    </message>
    <message>
        <source>File type</source>
        <translation>Dosya tipi</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Davranış</translation>
    </message>
    <message>
        <source>Change Action</source>
        <translation>Davranışı Değiştir</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Select one or several mime types then click &quot;Change Action&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>confgui::ConfIndexW</name>
    <message>
        <source>Can&apos;t write configuration file</source>
        <translation>Yapılandırma dosyası yazılamadı</translation>
    </message>
</context>
<context>
    <name>confgui::ConfParamFNW</name>
    <message>
        <source>Browse</source>
        <translation>Gözat</translation>
    </message>
</context>
<context>
    <name>confgui::ConfParamSLW</name>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
</context>
<context>
    <name>confgui::ConfSubPanelW</name>
    <message>
        <source>Global</source>
        <translation>Genel</translation>
    </message>
    <message>
        <source>Max. compressed file size (KB)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This value sets a threshold beyond which compressedfiles will not be processed. Set to -1 for no limit, to 0 for no decompression ever.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>confgui::ConfTopPanelW</name>
    <message>
        <source>Top directories</source>
        <translation>Üst dizinler</translation>
    </message>
    <message>
        <source>The list of directories where recursive indexing starts. Default: your home.</source>
        <translation>Özyinelemeli indesklemenin başlayacağı dizinlerin listesi. Öntanımlı: ev dizininiz.</translation>
    </message>
    <message>
        <source>Skipped paths</source>
        <translation>Atlanan yollar</translation>
    </message>
    <message>
        <source>These are names of directories which indexing will not enter.&lt;br&gt; May contain wildcards. Must match the paths seen by the indexer (ie: if topdirs includes &apos;/home/me&apos; and &apos;/home&apos; is actually a link to &apos;/usr/home&apos;, a correct skippedPath entry would be &apos;/home/me/tmp*&apos;, not &apos;/usr/home/me/tmp*&apos;)</source>
        <translation>Bunlar indekslemenin girmeyeceği dizinlerin adlarıdır.&lt;br&gt; * gibi özel karakterler içerebilir. İndeksleyici tarafından görülen yollar ile eşleşmelidir (örneğin: eğer en üst dizinler &apos;/home/ben&apos; ve &apos;/home&apos; içeriyorsa ve home &apos;/usr/home&apos; dizinine bağlantılı ise atlanacak dizin yolu &apos;/home/me/tmp*&apos; olmalıdır, &apos;/usr/home/me/tmp*&apos; değil)</translation>
    </message>
    <message>
        <source>Stemming languages</source>
        <translation>Sözcük kökleri ayrıştırılabilir diller</translation>
    </message>
    <message>
        <source>The languages for which stemming expansion&lt;br&gt;dictionaries will be built.</source>
        <translation>Kök ayrıştırma genişlemesi için sözlükleri&lt;br&gt;inşa edilecek olan diller.</translation>
    </message>
    <message>
        <source>Log file name</source>
        <translation>Günlük dosyasının adı</translation>
    </message>
    <message>
        <source>The file where the messages will be written.&lt;br&gt;Use &apos;stderr&apos; for terminal output</source>
        <translation>İletilerin yazılacağı dosya.&lt;br&gt;Uçbirim çıktısı için &apos;stderr&apos; kullanın</translation>
    </message>
    <message>
        <source>Log verbosity level</source>
        <translation>Günlük dosyası ayrıntı düzeyi</translation>
    </message>
    <message>
        <source>This value adjusts the amount of messages,&lt;br&gt;from only errors to a lot of debugging data.</source>
        <translation>Bu değer ileti boyutunu ayarlar,&lt;br&gt;sadece hatalardan hata ayıklama verilerine kadar.</translation>
    </message>
    <message>
        <source>Index flush megabytes interval</source>
        <translation>İndex düzeltme MB aralığı</translation>
    </message>
    <message>
        <source>This value adjust the amount of data which is indexed between flushes to disk.&lt;br&gt;This helps control the indexer memory usage. Default 10MB </source>
        <translation>Bu değer diske gönderilecek indekslenmiş veri miktarını ayarlar.&lt;br&gt;Bu indeksleyicinin bellek kullanımını kontrol etmeye yarar. Öntanımlı 10MB </translation>
    </message>
    <message>
        <source>Max disk occupation (%)</source>
        <translation>En yüksek disk kullanımı (%)</translation>
    </message>
    <message>
        <source>This is the percentage of disk occupation where indexing will fail and stop (to avoid filling up your disk).&lt;br&gt;0 means no limit (this is the default).</source>
        <translation>Bu disk kullanımının yüzdesidir ki bu orana erişildiğinde indeksleme durdurulur (diskin doldurulmasını engellemek için).&lt;br&gt;0 kısıtlama yok demektir (Öntanımlı).</translation>
    </message>
    <message>
        <source>No aspell usage</source>
        <translation>Aspell kullanımı yok</translation>
    </message>
    <message>
        <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful is aspell is absent or does not work. </source>
        <translation type="obsolete">İfade gösterme aracı için heceleme yakınlığı oluşturma özelliğini kapatır.&lt;br&gt; Aspell olmadığında ya da çalışmadığında kullanışlıdır. </translation>
    </message>
    <message>
        <source>Aspell language</source>
        <translation>Aspell dili</translation>
    </message>
    <message>
        <source>The language for the aspell dictionary. This should look like &apos;en&apos; or &apos;fr&apos; ...&lt;br&gt;If this value is not set, the NLS environment will be used to compute it, which usually works.To get an idea of what is installed on your system, type &apos;aspell config&apos; and look for .dat files inside the &apos;data-dir&apos; directory. </source>
        <translation>Aspell sözlükleri için dil. Bu &apos;en&apos; ya da &apos;fr&apos; gibi olmalıdır ...&lt;br&gt;Eğer bu değer ayarlanmazsa şimdi kullandığnız NLS çevresel değişkeni kullanılacaktır. Sisteminizde neyin yüklü olduğu hakkında bilgi almak için &apos;aspell config&apos; yazıp &apos;data-dir&apos; içerisindeki .dat dosyalarına bakın. </translation>
    </message>
    <message>
        <source>Database directory name</source>
        <translation>Veritabanı dizininin adı</translation>
    </message>
    <message>
        <source>The name for a directory where to store the index&lt;br&gt;A non-absolute path is taken relative to the  configuration directory. The default is &apos;xapiandb&apos;.</source>
        <translation>İndeksin duracağı dizinin adı&lt;br&gt;Eğer tam yol verilmezse yol yapılandırma  dizinine göre belirlenecek. Öntanımlı dizin adı &apos;xapiandb&apos;.</translation>
    </message>
    <message>
        <source>Use system&apos;s &apos;file&apos; command</source>
        <translation>Sistemdeki &apos;file&apos; komutunu kullan</translation>
    </message>
    <message>
        <source>Use the system&apos;s &apos;file&apos; command if internal&lt;br&gt;mime type identification fails.</source>
        <translation>İç mime tipi belirleme işlemi başarısız olursa&lt;br&gt; sistemdeki &apos;file&apos; komutunu kullan.</translation>
    </message>
    <message>
        <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful if aspell is absent or does not work. </source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
